### -*- coding: utf-8 -*- #############################################
#######################################################################
"""InstallBanner script for the Zope 3 based ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"

from zope.app.component.hooks import setSite
from zope.app.component import site
from ng.app.smartbanner.smartbannercontainer.smartbannercontainer import SmartBannerContainer
from ng.app.smartbanner.smartbanner.smartbanner import SmartBanner
from ng.app.smartbanner.smartbannercontainer.interfaces import ISmartBannerContainer
from logo import banners

def installBanner(context, **kw):
    """ Добавляет в сайт-менеджер папку banner и помещает в неё все
        необходимые баннеры
    """
    sm = context.getSiteManager()
    bc = sm[u'banner'] = SmartBannerContainer()
    for name,data,url,alt in banners :
        banner = bc[name] = SmartBanner(data=data)
        banner.alt = alt
        banner.url = url   

    sm.registerUtility(sm[u'banner'], provided=ISmartBannerContainer)

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################                                                 #

"""Search adapter for the Zope 3 neural content site

$Id: searchadapter.py 53379 2009-07-05 20:49:33Z cray $
"""
__author__  = "Andrey Orlov, 2007-02-20"
__license__ = "GPL"
__version__ = "$Revision: 53379 $"
__date__ = "$Date: 2009-07-06 00:49:33 +0400 (Пнд, 06 Июл 2009) $"
 
from zope.interface import Interface 

from interfaces import   ISearchClass, ISearchName, ISearchKeyword, ISearchBackName, ISearchBackKeyword
#from ng.app.remotefs.interfaces import IRemoteObject
from zope.cachedescriptors.property import Lazy
from os.path import normpath
from zope.security.proxy import removeSecurityProxy
from ng.adapter.mtime.interfaces import IMTime
from ng.adapter.path.interfaces import IPath
from pd.refchecker.refchecker import SearchReferenceAdapter
from ng.content.annotation.dictannotation.interfaces import IDictAnnotation
from ng.content.article.interfaces import IDocShort

import re
rspace = re.compile("\s+",re.U)

def catch(f) :
    def c(self,*kv,**kw) :
        try :
            return f(self,*kv,**kw)
        except TypeError,msg :
            return u""
    return c            

class SearchAdapter(object) :
    """Interface for index objects"""

    @property
    @catch
    def klass(self) :
        return ISearchClass(self.ob).klass

    @property
    @catch
    def name(self) :
        try :
            title = (IDocShort(self.ob).title.lower(),)
        except TypeError,msg :
            print msg
            title = ()            
        return [ re.sub(rspace," ",x).strip() for x in  IPath(self.ob).tailpath + title ]
        
    @property
    @catch
    def names(self) :
        return self.searchname.names
    
    @Lazy
    def searchname(self) :
        return ISearchName(self.ob)

    @property
    @catch
    def keywords(self) :
        return "\n".join(self.keyword)
        
    @Lazy
    def keyword(self) :
        try :
            return [re.sub(rspace," ",x.strip()).lower() for x in IDictAnnotation(self.ob).keyword]
        except TypeError :
            return []            

    #@property
    #@catch
    #def path(self) :
    #    return normpath(self.remoteobject.path)

    #@property
    #@catch
    #def prefix(self) :
    #    return unicode(self.remoteobject.prefix)

    #@Lazy
    #def remoteobject(self) :
    #    return IRemoteObject(self.ob)

    @property
    @catch
    def backname(self) :
        return ISearchBackName(self).backname

    @property
    @catch
    def backkeyword(self) :
        return ISearchBackKeyword(self).backkeyword

    @property
    @catch
    def mtime(self) :
        return IMTime(self.ob).mtime
        
    @property
    @catch
    def urlpath(self) :
        return IPath(self.ob).path
        
    @property
    def reference(self) :
        return SearchReferenceAdapter(self).reference        
        
        
        
            
                


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installAbout, installArticles, installMirrors, installNews, installRubric
and installRubrics scripts for the Zope 3 based ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"

from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site

from ng.content.article.division.division import Division
from ng.content.article.article.article import Article
from ng.app.objectqueue.interfaces import IObjectQueueAnnotation
from zope.app.container.interfaces import IContainer

def installAbout(context, **kw):
    """ Создаёт раздел about
    """
    about = context[u'about'] = Division()

    about.title = kw['about']
    about.abstract = kw['about_abstract']
    about.author = kw['author']
    IObjectQueueAnnotation(about).use = False
    
    return "Success"

def installDictionary(context, **kw):
    """ Create Dictionary Division """
    dictionary = context[u'dictionary'] = Division()

    dictionary.title = kw['dictionary']
    dictionary.author = kw['author']
    IObjectQueueAnnotation(dictionary).use = True
    IObjectQueueAnnotation(dictionary).islast = True
    
def installArticles(context, **kw):
    """ Создаёт раздел Articles
    """

    article = context[u'article'] = Division()

    article.title = kw['article']
    article.abstract = kw['article_abstract']
    article.author = kw['author']
    IObjectQueueAnnotation(article).use = False

    sm = context.getSiteManager()
    sm.registerUtility(context[u'article'], provided=IContainer, name=u'article')

    return "Success"

def installMirrors(context, **kw):
    """ Создаёт раздел Mirrors
    """
    mirror = context[u'mirror'] = Division()

    mirror.title = kw['mirror']
    mirror.abstract = kw['mirror_abstract']
    mirror.author = kw['author']
    IObjectQueueAnnotation(mirror).use = True
    IObjectQueueAnnotation(mirror).islast = True

    return "Success"

def installNews(context, **kw):
    """ Создаёт раздел News
    """
    news = context[u'news'] = Division()

    news.title = kw['news']
    news.abstract = kw['news_abstract']
    news.author = kw['author']

    sm = context.getSiteManager()
    sm.registerUtility(context[u'news'], provided=IContainer, name=u'news')
    IObjectQueueAnnotation(news).use = True
    IObjectQueueAnnotation(news).islast = False
    IObjectQueueAnnotation(news).order = u'straight'
    IObjectQueueAnnotation(news).maxlen = 40
    
    return "Success"

def installRubrics(context, **kw) :
    rubrics = kw['rubrics']
    
    for rubric in rubrics :
       division = Division()
       division.title = rubric.title
       division.abstract = rubric.abstract
       division.author = kw['author']
       context[rubric.name] = division
       IObjectQueueAnnotation(division).use = True
       IObjectQueueAnnotation(division).islast = False

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Interfaces for the Zope 3 based ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from zope.interface import Interface

from zope.schema import Text, TextLine, Field, Bool, Datetime, Tuple, Object
from zope.app.container.interfaces import IContained, IContainer
from zope.app.container.constraints import ItemTypePrecondition
from zope.app.container.constraints import ContainerTypesConstraint
from zope.app.file.interfaces import IImage
from zope.schema.interfaces import IField


class IRubricDescription(Interface) :

    name = TextLine(
        title=u'name',
        default=u'',
        required=True,
        )

    title = TextLine(
        title=u'Title',
        default=u'',
        required=False,
        )

    abstract = Text(
        title=u'Abstract',
        default=u'',
        required=False,
        )


class IInstall(Interface) :
    
    title = TextLine(title=u'title',
                           default=u'Dream Bot Site',
                           required=True)

    author  = TextLine(title=u'author',
                           default=u'Stepan Lomov',
                           required=True)


    article  = TextLine(title=u'Article title',
                               default=u'Публикации',
                               required=False)
                               
    about = TextLine(title=u'About title',
                           default=u'О проекте',
                           required=False)

    mirror = TextLine(title=u'Mirror title',
                              default=u'Зеркала',
                              required=False)

    dictionary = TextLine(title=u'Dictionary title',
                              default=u'Толковый словарь',
                              required=False)

    news = TextLine(title=u'News title',
                           default=u'Новости',
                           required=False)

    rubricator =  TextLine(title=u'Rubricator title',
                                 default=u'Рубрикатор',
                                 required=False)

    profile = TextLine(title=u'Profile title',
                                 default=u'Профили',
                                 required=True)

    pam_prefix = TextLine(title=u'Prefix PAM',
                            default=u'openid.',
                            required=True)

    pam_redirect = TextLine(title=u'Redirect PAM',
                            default=u'http://greenfuture.ru/profile/%s/@@register.html',
                            required=True)


    vh_path = TextLine(title=u'Virtual site path',
                        default = u'/++skin++greenpsy/Psy/++vh++http:greenfuture.ru:80/++//',
                        required = True)
        
    vh_site = TextLine(title=u'Virtual site',
                        default = u'http://greenfuture.ru/',
                        required = True)
        
    rubrics = Tuple(
        title=u'Site rubrics',
        description=u'Site rubrics',
        required=False,
        default=(),
        value_type=Object(title=u'site rubric', schema = IRubricDescription),
        )
        
    logo = Object(
        title = u"Logo",
        description = u"Logo",
        schema = IImage,
        )



### -*- coding: utf-8 -*- #############################################
#######################################################################                                                 #

"""Search adapter for the Zope 3 neural content site

$Id: photosearchadapter.py 52128 2008-12-23 08:42:10Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51189 $"
__date__ = "$Date: 2008-06-26 15:21:11 +0400 (Чтв, 26 Июн 2008) $"
 
from zope.interface import Interface 
from zope.cachedescriptors.property import Lazy
from ng.content.article.interfaces import IDocShort
from ng.site.content.search.searchadapter import SearchAdapter

class PhotoSearchAdapter(SearchAdapter) :
    """Interface for index objects"""

    @Lazy
    def iface(self) :
        return IDocShort(self.ob)

    @property
    def title(self) :
        return self.iface.title

    @property
    def abstract(self) :
        return self.iface.abstract

    
                    
        
            
                


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""handleAdded, handleModified and handleRemoved scripts for the Zope 3
based ng.app.objectqueue package

$Id: renamehandler.py 53390 2009-07-08 11:01:43Z cray $
"""
__author__  = "Yegor Shershnev, 2008"
__license__ = "GPL"
__version__ = "$Revision: 53390 $"

from zope.interface import Interface
from zope.interface import implements,implementedBy
from zope.proxy import removeAllProxies
from renameexception import RenameException

#from ng.content.article.interfaces import IDocShort

from zope.copypastemove.interfaces import IContainerItemRenamer
from zope.app.container.interfaces import IContained
from zope.app.container.interfaces import INameChooser

def renameHandler(ob, event) :

    print ob
    parent = IContained(ob).__parent__
    
    title = INameChooser(parent).chooseName(None,ob)
    name = IContained(ob).__name__
    print name, title
    if name != title :
        print "Raise!"
        IContainerItemRenamer(parent).renameItem(name,title)
            
        raise RenameException(ob)
        


### -*- coding: utf-8 -*- #############################################
#######################################################################
""" Special widgets for ng.app.content.install addform

$Id: widgets.py 50586 2008-02-07 06:09:55Z corbeau $
"""
__author__  = u"Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 50586 $"


from zope.app.form import CustomWidgetFactory
from ng.lib.objectwidget import ObjectWidget
from zope.app.form.browser import TupleSequenceWidget
from zope.app.file.image import Image
from rubricdescription import RubricDescription


LogoWidget = CustomWidgetFactory(
    ObjectWidget,
    Image
    )


RubricWidget = CustomWidgetFactory(
    TupleSequenceWidget,
    subwidget=CustomWidgetFactory(
        ObjectWidget,
        RubricDescription
        )
    )



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Dwitchable markers

$Id: interfaces.py 51962 2008-10-23 21:52:47Z cray $
"""
__author__  = "Andrey Orlov"
__license__ = "GPL"
__version__ = "$Revision: 51962 $"
__date__ = "$Date: 2008-10-24 01:52:47 +0400 (Птн, 24 Окт 2008) $"
 
from ng.content.article.interfaces import IDocFormatSwitcher, IArticleDesignSwitcher
from zope.interface import Interface

class IArticleDivided(IArticleDesignSwitcher) :
    "Divided Design"
    pass

class IArticlePage(IArticleDesignSwitcher):
    "Page Design"
    pass

class IArticleREST(IDocFormatSwitcher) :
    "Restructured text data"
    pass

class IArticleST(IDocFormatSwitcher):
    "Structured text data"
    pass

class IArticleASIS(IDocFormatSwitcher):
    "Preformated Text"
    pass

class IArticleHTML(IDocFormatSwitcher):
    "HTML text data"
    pass


class IDivisionDesignSwitcher(Interface):
    "Default Design"
    pass

class IDivisionDictionarySwitcher(IDivisionDesignSwitcher) :
    "Dictionary design "

class IDivisionItemSwitcher(IDivisionDesignSwitcher) :
    "Item design "
    
    



### -*- coding: utf-8 -*- #############################################
######################################################################

# Make it a Python package

import os.path
all = ['logo', 'banners' ]
logo = open(os.path.join(__path__[0],'nuclearpig_logo_demo.gif')).read()

def bannertuple(name,url,alt) :
    return (unicode(name),open(os.path.join(__path__[0],name)).read(),url,unicode(alt))

banner_zope =  bannertuple('banner_zope.gif','http://www.zope.org','Zope')
banner_thedream_whiteblue = bannertuple('banner_thedream_whiteblue.png','http://dreambot.ru','The Dream Bot Info Site')
banners = [ banner_zope, banner_thedream_whiteblue]


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Interface used to accept browser form of nickname from
author field.

$Id: interfaces.py 51347 2008-07-10 20:10:15Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 51347 $"
 
from zope.interface import Interface

class IOwner2Nickname(Interface):

    def __call__(name):
        """Returns a nickname surround by link to profile for entered name"""

        


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Adapter owner to nickname in browse represetative

$Id: owner2nicknameadapter.py 52560 2009-02-11 20:08:02Z cray $
"""
__author__  = "Andrey Orlov"
__license__ = "GPL"
__version__ = "$Revision: 52560 $"

from zope.app.zapi import getUtility
from zope.app.catalog.interfaces import ICatalog
from ng.adapter.adaptiveurl.adaptiveurl import adaptiveURL
from ng.content.profile.profileannotation.interfaces import IProfileAnnotation

class Owner2NicknameAdapter(object) :
    """ Owner 2 nickname adapter """

    def __init__(self,context,request) :
        self.context = context
        self.request = request
        
    def __getitem__(self,author) :
      if author is None :
         return u""
         
      for profile in getUtility(ICatalog,context=self.context) \
                          .searchResults(
                              profile=( unicode(author), unicode(author) )
                          ) :
          return """<a class="nickname" href="%(href)s"> %(author)s</a>""" % {
                    "author" : IProfileAnnotation(profile).nickname,
                    "href" : adaptiveURL(profile,self.request)
                  }
      else :
          return """%(author)s""" % { 'author' : author }




### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Product class for the Zope 3 based product package

$Id: doctitle2titleadapter.py 49905 2008-01-08 16:20:57Z cray $
"""
__author__  = "Andrey Orlov, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49905 $"

from zope.component import adapts
from ng.content.article.interfaces import IDocTitle
from ng.adapter.title.contained2titleadapter import Contained2TitleAdapter

class DocTitle2TitleAdapter(Contained2TitleAdapter) :

    adapts(IDocTitle)
    
    @property
    def title(self) :
        title = IDocTitle(self.context).title
        if not title :
            title = super(DocTitle2TitleAdapter,self).title        
        return title



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installLogo script for the Zope 3 based ng.site.content.install package

$Id: install_logo.py 50586 2008-02-07 06:09:55Z corbeau $
"""
__author__  = "Yegor Shershnev, 2008"
__license__ = "GPL"
__version__ = "$Revision: 50586 $"

from zope.app.file.interfaces import IImage
from zope.app.file.image import Image
from logo import logo

def installLogo(context, **kw):
    """ Создаёт в основной контейнере файл с логотипом сайта и именем logo
    """
    if kw[u'logo'].getSize() :
        context.logo = kw[u'logo']
    else :
        context.logo = Image(data=logo)
    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installIntIds script for the Zope 3 based ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from zope.app.intid.interfaces import IIntIds
from zope.app.intid import IntIds


def installIntIds(context, **kw):
    """ Устанавливает в сайт-менеджере контекста генератор уникальных
        идентификаторов (IntIds) и регистрирует его
    """
    # Получаем сайт-менеджер
    sm = context.getSiteManager()
    # Добавляем в сайт-менеджер утилиту IntIds (генератор уникальных
    # идентификаторов)
    sm[u'IntIds'] = IntIds()
    # Регистрируем добавленную утилиту без имени с интерфейсом IIntIds
    sm.registerUtility(sm[u'IntIds'], provided=IIntIds)
    # Регистрируем добавленную утилиту с интерфейсом IIntIds и именем intid
    sm.registerUtility(sm[u'IntIds'], provided=IIntIds, name=u'intid')
    sm[u'IntIds'].register(context)

    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""ErrorView - is base class for zope3 errors

$Id: renameview.py 53390 2009-07-08 11:01:43Z cray $
"""
__author__  = "Andrey Orlov, 2009"
__license__ = "GPL"
__version__ = "$Revision: 53390 $"

from zope.publisher.browser import BrowserView
from zope.app.exception.systemerror import SystemErrorView
from zope.traversing.browser.absoluteurl import absoluteURL

class RenameView(BrowserView,SystemErrorView) :
    """Class for redirect view """
    def __init__(self,context,request) :
        super(RenameView,self).__init__(context,request)
        request.response.redirect(absoluteURL(context.ob,request) "/@@commonedit.html")

    def __call__(self,*kv) :
      return "Please, wait"
      


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Adapter article to rss-entry

$Id: article2rssentryadapter.py 52181 2008-12-25 11:15:40Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 52181 $"

from zope.app.zapi import getUtility
from zope.component import ComponentLookupError
from zope.traversing.browser import absoluteURL
from ng.app.converter.object2psadapter.interfaces import IPropertySheet
from ng.adapter.mtime.interfaces import IMTime
from persistent.interfaces import IPersistent
from zope.security.proxy import removeSecurityProxy
import uuid
from zope.app.zapi import getUtility
from zope.app.catalog.interfaces import ICatalog
from ng.adapter.adaptiveurl.adaptiveurl import adaptiveURL
from ng.content.profile.profileannotation.interfaces import IProfileAnnotation

class Article2RSSEntryAdapter(object) :
    """ Adapter article to rss-entry """
    def __init__(self,context,request) :
        ps = IPropertySheet(context)
        self.title = ps['title']
        self.updated = IMTime(context).strftime("%Y-%m-%dT%H:%M:%SZ")
        self.summary = ps['summary'] or ps['autosummary']
        self.id = uuid.uuid3(uuid.NAMESPACE_OID,IPersistent(removeSecurityProxy(context))._p_oid).urn
        self.link = absoluteURL(context,request)
        for profile in getUtility(ICatalog,context=context) \
                            .searchResults(
                                profile=( unicode(context.author), unicode(context.author) )
                            ) :
            self.author = IProfileAnnotation(profile).nickname
        else :
            self.author = context.author or ""

    title = ""
    updated = ""
    summary = ""
    id = ""
    link = ""
    author = ""    



### -*- coding: utf-8 -*- #############################################
#######################################################################                                                 #

"""Class adapter for the Zope 3 based search package

$Id: searchclassadapter.py 1223 2007-03-03 01:37:10Z cray $
"""
__author__  = "Andrey Orlov, 2007-02-20"
__license__ = "GPL"
__version__ = "$Revision: 1223 $"
__date__ = "$Date: 2007-03-03 04:37:10 +0300 (Сбт, 03 Мар 2007) $"
 
from zope.interface import Interface
from zope.schema import Text, TextLine, Datetime, Tuple, Set, Field

class SearchClassAdapter(object) :
    """Interface for index objects"""

    def __init__(self,ob) :
        self.klass = u"%s.%s" % ( ob.__class__.__module__,ob.__class__.__name__ )



### -*- coding: utf-8 -*- #############################################
#######################################################################                                                 #

"""Class adapter for the Zope 3 based search package

$Id: searchnameadapter.py 49522 2007-12-18 07:39:29Z cray $
"""
__author__  = "Andrey Orlov, 2007-02-20"
__license__ = "GPL"
__version__ = "$Revision: 49522 $"
__date__ = "$Date: 2007-12-18 10:39:29 +0300 (Втр, 18 Дек 2007) $"
 
from zope.interface import Interface
from zope.schema import Text, TextLine, Datetime, Tuple, Set, Field
import re

class SearchNameAdapter(object) :
    """Interface for index objects"""

    def __init__(self,ob) :
        self.name = [re.sub("\s+"," ",ob.__name__)]
        self.names = "\n".join(self.name)
        #]+ob.__name__.split(".")



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installConverter and installMapper scripts for the Zope 3 based
ng.site.content.install package

$Id: product.py 49265 2008-01-08 12:18:26Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 49265 $"


from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site
from zope.app.component.site import SiteManagementFolder

from ng.app.converter.converter.converterhead.converterhead import ConverterHead
from ng.app.converter.converter.converterrest.converterrest import ConverterReST
from ng.app.converter.converter.converterlightrest.converterlightrest import ConverterLightReST
from ng.app.converter.converter.converterregexp.converterregexp import ConverterRegexp
from ng.app.converter.converter.converterst.converterst import ConverterST
from ng.app.converter.converter.converterchain.converterchain import ConverterChain
from ng.app.converter.converter.convertercontainer.convertercontainer import ConverterContainer
from ng.app.converter.converter.converterxslt.converterxslt import ConverterXSLT
from ng.app.converter.converter.converterselect.converterselect import ConverterSelect

from ng.app.converter.converter.converterhead.interfaces import IConverterHead
from ng.app.converter.converter.converterrest.interfaces import IConverterReST
from ng.app.converter.converter.converterlightrest.interfaces import IConverterLightReST
from ng.app.converter.converter.converterregexp.interfaces  import IConverterRegexp
from ng.app.converter.converter.converterst.interfaces import IConverterST
from ng.app.converter.converter.converterchain.interfaces import IConverterChain
from ng.app.converter.converter.convertercontainer.interfaces import IConverterContainer
from ng.app.converter.converter.converterxslt.interfaces import IConverterXSLT
from ng.app.converter.converter.converterselect.interfaces import IConverterSelect
from ng.app.converter.converter.converterannotator.interfaces import IConverterAnnotator

from ng.app.converter.cachestore.cachestore import Cachestore

from ng.app.converter.converter.converterchain.converterchain import ConverterChain
from ng.app.converter.converter.converterannotator.converterannotator import ConverterAnnotator
from ng.app.converter.converter.interfaces import IConverter
from ng.app.converter.cachestore.interfaces import ICachestore

from ng.app.converter.mapper.mapperobject.mapperobject import MapperObject
from ng.app.converter.mapper.mapperobject.interfaces import IMapperObject
from ng.app.converter.mapper.mapperinterface.mapperinterface import MapperInterface
from ng.app.converter.mapper.mapperattribute.mapperattribute import MapperAttribute
from ng.app.converter.mapper.mapperattributeitem.mapperattributeitem import MapperAttributeItem


def installConverter(context, **kw):
    """ Install all converters """
    sm = context.getSiteManager()
    converter = sm[u'converter'] = SiteManagementFolder()
    base = converter[u'base'] = SiteManagementFolder()
    
    for name,regexp,format in (
            ('absolute_url','(?<==")(?P<url>%40%40searchpage)','http://dreambot.ru/%(url)s'),
            ('comment-killer','(?m)^\s*(###|\*\*\*|#(TODO|FIXME|Q|A))\s*.*$',' '),
            ('degenerator','<meta name="generator" content="Docutils 0.4: http://docutils.sourceforge.net/" />',' '),
            ('image-center-rest','(?P<tag><img\s+alt=".*"\s+src=".*"\s+/>)','<center>%(tag)s</center>'),
            ('image-rest','\.\.\s+image::\s+(?P<href>[^\s]+)','.. image:: %(href)s/smartimagecontainer/full/get'),
            ('keyword-killer','\[keyword:(?P<word>[^\]]+):(?P<word2>[^\]]+)\]','%(word2)s'),
            ('keyword-killer-simple','\[keyword:(?P<word>[^:\]]+)\]','%(word)s'),
            ('keyword-reference','\[keyword:(?P<word>[^\]]+):(?P<word2>[^\]]+)\]','<a title="Словарь: %(word)s" href="%%40%%40searchpage.html?keyword.any_of:record:tuple=%(quote(word))s">%(word2)s</a>'),
            ('keyword-reference-simple','\[keyword:(?P<word>[^:\]]+)\]','<a title="Словарь: %(word)s" href="%%40%%40searchpage.html?keyword.any_of:record:tuple=%(quote(word))s">%(word)s</a>'),
            ('killdivabstractstyle','\s+div.abstract\s+{\s+margin:\s+2em\s+5em\s+}',' '),
            ('killrestchaptersign','(?P<char>.)(?P=char){10,}',' '),
            ('name-killer','\[name:(?P<word>[^\]]+):(?P<title>[^\]]+)\]','%(title)s'),
            ('name-killer-simple','\[name:(?P<word>[^\]]+)\]','%(word)s'),
            ('name-reference','\[name:(?P<word>[^\]]+):(?P<title>[^\]]+)\]','<a title="Документ: %(word)s" href="%%40%%40searchpage.html?name.any_of:record:tuple=%(quote(word))s">%(title)s</a>'),
            ('name-reference-simple','\[name:(?P<word>[^\]]+)\]','<a title="Документ: %(word)s" href="%%40%%40searchpage.html?name.any_of:record:tuple=%(quote(word))s">%(word)s</a>'),
            ('reference','((?<=\s|>)|(?<=^))(?P<href>http://[^\s<]+)((?=\s|<|$))','<a href="%(href)s">%(href)s</a>'),
            ('st-reference','"(?P<title>[^:"]*)":(?P<href>[^:]+://\S+)','<a title="Ссылка на: %(href)s" href="%(href)s">%(title)s</a>'),
            ('st-reference-make','((?<=\s|>)|(?<=^))(?P<href>http://[^\s<]+)((?=\s|<|$))','"%(href)s":%(href)s'),
        ) :
        base[name] = ConverterRegexp(regexp,format)                        
        sm.registerUtility(base[name], provided=IConverterRegexp, name=name)

    base[u'asis'] = ConverterHead(
        regexp=u'(?ums)^(?P<body>.*)$',
        format=u'<pre>%(body)s</pre>',
        bytes=102400000,
        lines=100000            
        )
        
    sm.registerUtility(base[u'asis'], provided=IConverterHead, name=u'asis')        

    base[u'head'] = ConverterHead(
        regexp=u'(?ums)^\s*(?P<body>.{,1024})',
        format=u'<p>%(body)s ...</p>',
        bytes=1024,
        lines=1000000            
        )
        
    sm.registerUtility(base[u'head'], provided=IConverterHead, name=u'head')        

    base[u'annotator'] = ConverterAnnotator("""
      alt
      altlinux
      altlinux team
      apt
      apt-get
      bot
      btreecontainer
      btreefolder
      b-дерево
      cm
      corba
      daedalus
      distutils
      django
      dreambot
      easy_install
      factory
      five
      handler
      heapq
      invariant
      irequest
      keysolutions
      ks
      lazy
      lazy evaluation
      libxmlrpc
      namespace
      object root
      plone
      pypi
      pypo
      python
      python package index
      python policy
      python policy (pypo)
      rbn
      request
      rest
      restructured text
      robot
      ror
      rpas
      rpm
      rpm-build-python
      rst
      ruby
      rubyonrails
      ruby on rails
      self-organizingmap
      setuptools
      sisyphus
      sitemanager
      soap
      som
      subscriber
      subscribers
      traverse
      traversing
      ttw
      turing
      twisted
      websom
      widget
      xmlrpc
      xmlrpclib
      zc.buildout
      zcml
      zodb
      zope
      zope2
      zope3
      zope page template
      zpt
      адаптер
      адаптер вида
      адаптер пространства имен
      а́лан матисон тью́ринг 
      аннотация
      блокирующий вызов
      бот
      вид
      джанго
      дистанция левенштейна
      запрос
      инстанция zope
      инструмент
      интерфейс
      интерфейс-маркер
      канал
      канал событий
      ключевые решения
      компонент
      компонентная модель
      кр
      кс
      левенштейн
      ленивые вычисления
      мультиадаптер
      неймспейс
      обработчик события
      объект
      объекта
      ограничения
      ооп
      отложенные вычисления
      питон
      подписной адаптер
      поле
      поле схемы
      пространство имен
      рабочая область zope
      расстояние левенштейна
      реестр адаптеров
      реестр утилит
      сеть радиального базиса
      синхронный вызов
      скин
      схема
      схема интерефейса
      схема интерфейса
      траверс
      тьюринг
      утилита
      фабрика
      экземпляр zope
    """)
    sm.registerUtility(base[u'annotator'], provided=IConverterAnnotator, name=u'annotator')        

    base[u'converterrest'] = ConverterReST()
    sm.registerUtility(base[u'converterrest'], provided=IConverterReST, name=u'converterrest')        

    base[u'converterlightrest'] = ConverterLightReST()
    sm.registerUtility(base[u'converterlightrest'], provided=IConverterLightReST, name=u'converterlightrest')        

    base[u'converterst'] = ConverterST()
    sm.registerUtility(base[u'converterst'], provided=IConverterST, name=u'converterst')        

    for name, chain in (
        ( u'converter:ANNOTATOR',( u'comment-killer', u'killrestchaptersign', u'annotator', u'head', u'keyword-reference', u'keyword-reference-simple', u'name-reference', u'name-reference-simple', u'reference', u'st-reference' )),
        ( u'converter:ASIS',( u'asis', u'keyword-reference', u'keyword-reference-simple', u'name-reference', u'name-reference-simple', u'st-reference' )),
        ( u'converter:AUTOSUMMARY',( u'converter:ANNOTATOR', u'absolute_url' )),
        ( u'converter:Export',( u'comment-killer', u'keyword-killer', u'keyword-killer-simple', u'name-killer', u'name-killer-simple', u'st-reference-make' )),
        ( u'converter:ReST+WIKI',( u'comment-killer', u'converterrest', u'degenerator', u'keyword-reference', u'keyword-reference-simple', u'name-reference', u'name-reference-simple', u'reference', u'st-reference', u'killdivabstractstyle' )),
        ( u'converter:ST+WIKI',( u'comment-killer', u'converterst', u'keyword-reference', u'keyword-reference-simple', u'name-reference', u'name-reference-simple', u'reference', u'st-reference' )),
        ( u'converter:LightReST+WIKI',( u'comment-killer', u'converterlightrest', u'keyword-reference', u'keyword-reference-simple', u'name-reference', u'name-reference-simple', u'reference', u'st-reference' )),
        ( u'converter:SUMMARY',( u'converter:LightReST+WIKI', u'absolute_url' )),
        ) :

        converter[name] = ConverterChain()
        converter[name].chain = chain
        sm.registerUtility(converter[name], provided=IConverterChain, name=name)

    converter[u'converter:XSLT+SELECT'] = ConverterContainer()
    converter[u'converter:XSLT+SELECT']['0-ConverterXSLT'] = ConverterXSLT(html_charset='utf8')
    converter[u'converter:XSLT+SELECT']['1-ConverterSelect'] = ConverterSelect(
        dwin = 50,
        lwin = 100,
        threshold = 3,
    )

    sm.registerUtility(converter[u'converter:XSLT+SELECT'], provided=IConverterContainer, name=u'converter:XSLT+SELECT')

    sm[u'Cachestore'] = Cachestore()
    sm[u'Cachestore'].intIdsName= u'intid'
    sm.registerUtility(sm[u'Cachestore'], provided=ICachestore)

    return "Success"

def installMapper(context, **kw):
    """ Устанавливает MapperObject со всеми его внутренностями
    """

    sm = context.getSiteManager()

    mo = sm['converter'][u'MapperObject'] = MapperObject()

    sm.registerUtility(mo, provided=IMapperObject)

    names = (
     [u'ng.content.article.division.interfaces.IDivision',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.content.article.interfaces.IDocFormatSwitcher',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'auto': (u'body',u'converter:ANNOTATOR'),
       u'autosummary': (u'body',u'converter:AUTOSUMMARY'),
       u'body': (u'body',u'converter:ASIS'),
       u'export': (u'body',u'converter:Export'),
       u'summary': (u'abstract',u'converter:SUMMARY'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.content.article.interfaces.IDocShort',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'summary': (u'abstract',u'converter:SUMMARY'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.content.article.maincontainer.interfaces.IMainPage',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.site.content.switcher.interfaces.IArticleASIS',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'auto': (u'body',u'converter:ANNOTATOR'),
       u'autosummary': (u'body',u'converter:AUTOSUMMARY'),
       u'body': (u'body',u'converter:ASIS'),
       u'export': (u'body',u'converter:Export'),
       u'summary': (u'abstract',u'converter:SUMMARY'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.site.content.switcher.interfaces.IArticleHTML',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'body': (u'body',u'converter:XSLT+SELECT'),
       u'export': (u'body',u'converter:Export'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.site.content.switcher.interfaces.IArticleREST',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'auto': (u'body',u'converter:ANNOTATOR'),
       u'autosummary': (u'body',u'converter:AUTOSUMMARY'),
       u'body': (u'body',u'converter:ReST+WIKI'),
       u'export': (u'body',u'converter:Export'),
       u'summary': (u'abstract',u'converter:SUMMARY'),
       u'title': (u'title',u'reference'),
     }],
     [u'ng.site.content.switcher.interfaces.IArticleST',
      u'ng.app.converter.object2psadapter.interfaces.IPropertySheet',
      {
       u'abstract': (u'abstract',u'converter:LightReST+WIKI'),
       u'auto': (u'body',u'converter:ANNOTATOR'),
       u'autosummary': (u'body',u'converter:AUTOSUMMARY'),
       u'body': (u'body',u'converter:ST+WIKI'),
       u'export': (u'body',u'converter:Export'),
       u'summary': (u'abstract',u'converter:SUMMARY'),
       u'title': (u'title',u'reference'),
     }],
    )

    
    for i in range(len(names)):
        mo[names[i][0]] = MapperInterface()
        mo[names[i][0]][names[i][1]] = MapperAttribute()
        for j in names[i][2].keys():
            mai = mo[names[i][0]][names[i][1]][j] = MapperAttributeItem()
            mai.attr = names[i][2][j][0]
            mai.converter = names[i][2][j][1]
    
    return "Success"



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""ErrorView - is base class for zope3 errors

$Id: renameexception.py 53390 2009-07-08 11:01:43Z cray $
"""
__author__  = "Andrey Orlov, 2009"
__license__ = "GPL"
__version__ = "$Revision: 53390 $"


from zope.interface import implements
from interfaces import IRenameException

class RenameException(Exception) :
    implements(IRenameException)
    
    def __init__(self,ob) :
        self.ob = ob
        self.args = [ob]        


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""The definitions of exceptiion

$Id: interfaces.py 53390 2009-07-08 11:01:43Z cray $
"""
__author__  = "Andrey Orlov"
__license__ = "GPL"
__version__ = "$Revision: 53390 $"

from zope.interface import Interface
from zope.schema import Field

class IRenameException(Interface) :
    """ Basic Skin """

    ob = Field(title=u"New object")    